package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TextMessageLogMapper;
import com.ruoyi.system.domain.TextMessageLog;
import com.ruoyi.system.service.ITextMessageLogService;

/**
 * 短信记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-07-20
 */
@Service
public class TextMessageLogServiceImpl implements ITextMessageLogService 
{
    @Autowired
    private TextMessageLogMapper textMessageLogMapper;

    /**
     * 查询短信记录
     * 
     * @param id 短信记录ID
     * @return 短信记录
     */
    @Override
    public TextMessageLog selectTextMessageLogById(Long id)
    {
        return textMessageLogMapper.selectTextMessageLogById(id);
    }

    /**
     * 查询短信记录列表
     * 
     * @param textMessageLog 短信记录
     * @return 短信记录
     */
    @Override
    public List<TextMessageLog> selectTextMessageLogList(TextMessageLog textMessageLog)
    {
        return textMessageLogMapper.selectTextMessageLogList(textMessageLog);
    }

    /**
     * 新增短信记录
     * 
     * @param textMessageLog 短信记录
     * @return 结果
     */
    @Override
    public int insertTextMessageLog(TextMessageLog textMessageLog)
    {
        textMessageLog.setCreateTime(DateUtils.getNowDate());
        return textMessageLogMapper.insertTextMessageLog(textMessageLog);
    }

    /**
     * 修改短信记录
     * 
     * @param textMessageLog 短信记录
     * @return 结果
     */
    @Override
    public int updateTextMessageLog(TextMessageLog textMessageLog)
    {
        textMessageLog.setUpdateTime(DateUtils.getNowDate());
        return textMessageLogMapper.updateTextMessageLog(textMessageLog);
    }

    /**
     * 批量删除短信记录
     * 
     * @param ids 需要删除的短信记录ID
     * @return 结果
     */
    @Override
    public int deleteTextMessageLogByIds(Long[] ids)
    {
        return textMessageLogMapper.deleteTextMessageLogByIds(ids);
    }

    /**
     * 删除短信记录信息
     * 
     * @param id 短信记录ID
     * @return 结果
     */
    @Override
    public int deleteTextMessageLogById(Long id)
    {
        return textMessageLogMapper.deleteTextMessageLogById(id);
    }
}
